Encoding.default_external = "UTF-8" if defined? Encoding

#require 'nanoc'
require 'minitest/autorun'

#needed for some tests
require 'yard'

#$VERBOSE = 1

#$LOAD_PATH.unshift(File.expand_path(File.dirname(__FILE__) + '/..'))

# require our test helper so we don't have to in each individual test
require './test/helper'

test_files = Dir['./test/base/core_ext/*_spec.rb'] + Dir['./test/{base,cli,data_sources,filters,helpers,tasks}/**/test_*.rb']
#test_files = Dir['test/filters/test_*.rb']
#test_files = Dir['test/filters/test_bluecloth.rb']
test_files.each { |f| require f }
